#
# spec file for package python-oslo.versionedobjects
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.versionedobjects
Version:        3.4.0
Release:        1.1
Summary:        Oslo Versioned Objects library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.versionedobjects
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.versionedobjects/oslo.versionedobjects-3.4.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-iso8601 >= 0.1.11
BuildRequires:  python3-jsonschema
BuildRequires:  python3-oslo.concurrency >= 3.26.0
BuildRequires:  python3-oslo.config >= 5.2.0
BuildRequires:  python3-oslo.context >= 2.19.2
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.log >= 3.36.0
BuildRequires:  python3-oslo.messaging >= 5.29.0
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-oslo.utils >= 4.7.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr
BuildRequires:  python3-stestr
BuildArch:      noarch

%description
oslo.versionedobjects library deals with DB schema being at different versions
than the code expects, allowing services to be operated safely during upgrades.
It enables DB independent schema by providing an abstraction layer, which
allows us to support SQL and NoSQL Databases. oslo.versionedobjects is also
used in RPC APIs, to ensure upgrades happen without spreading version dependent
code across different services and projects.

%package -n python3-oslo.versionedobjects
Summary:        Oslo Versioned Objects library
Requires:       python3-WebOb >= 1.7.1
Requires:       python3-iso8601 >= 0.1.11
Requires:       python3-netaddr >= 0.7.18
Requires:       python3-oslo.concurrency >= 3.26.0
Requires:       python3-oslo.config >= 5.2.0
Requires:       python3-oslo.context >= 2.19.2
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.log >= 3.36.0
Requires:       python3-oslo.messaging >= 5.29.0
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 4.7.0

%description -n python3-oslo.versionedobjects
oslo.versionedobjects library deals with DB schema being at different versions
than the code expects, allowing services to be operated safely during upgrades.
It enables DB independent schema by providing an abstraction layer, which
allows us to support SQL and NoSQL Databases. oslo.versionedobjects is also
used in RPC APIs, to ensure upgrades happen without spreading version dependent
code across different services and projects.

This package contains the Python 3.x module.

%package -n python-oslo.versionedobjects-doc
Summary:        osloversionedobjects library - Documentation
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-oslo.versionedobjects-doc
This package contains documentation files for %{name}.

%prep
%autosetup -p1 -n oslo.versionedobjects-3.4.0
%py_req_cleanup

%build
%py3_build

PYTHONPATH=. PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
rm -r doc/build/html/.{doctrees,buildinfo}

%install
%py3_install

%check
%{openstack_stestr_run}

%files -n python3-oslo.versionedobjects
%license LICENSE
%{python3_sitelib}/oslo_versionedobjects
%{python3_sitelib}/*.egg-info

%files -n python-oslo.versionedobjects-doc
%license LICENSE
%doc doc/build/html README.rst

%changelog
* Mon Sep  2 2024 cloud-devel@suse.de
- update to version 3.4.0
  - reno: Update master for unmaintained/wallaby
  - reno: Update master for unmaintained/zed
  - Update master for stable/2024.1
  - Replace usage of pytz
  - Remove old excludes
  - reno: Update master for unmaintained/xena
  - reno: Update master for unmaintained/victoria
* Sun Mar 24 2024 cloud-devel@suse.de
- removed 0001-Avoid-TypeError-when-building-for-Sphinx-6.1.1-and-a.patch
- update to version 3.3.0
  - Avoid TypeError when building for Sphinx 6.1.1 and above
  - Bump hacking
  - Update python classifier in setup.cfg
  - coveragerc: Remove non-existent path
  - reno: Update master for unmaintained/yoga
  - Update master for stable/2023.2
* Thu Dec 28 2023 cloud-devel@suse.de
- update to version 3.2.0
  - Update master for stable/2023.1
  - Imported Translations from Zanata
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Bump bandit and make oslo.versionedobjects compatible with latest rules
  - Moves supported python runtimes from version 3.8 to 3.10
* Mon Mar  6 2023 cloud-devel@suse.de
- added 0001-Avoid-TypeError-when-building-for-Sphinx-6.1.1-and-a.patch
- update to version 3.1.0
  - Update master for stable/zed
  - Add Python3 antelope unit tests
* Sun Oct  2 2022 cloud-devel@suse.de
- update to version 3.0.1
  - Python3.11: Do not use inspect.ArgSpec
* Tue Aug 16 2022 cloud-devel@suse.de
- update to version 3.0.0
  - Add Python3 zed unit tests
  - Drop python3.6/3.7 support in testing runtime
  - Imported Translations from Zanata
  - Update master for stable/yoga
  - Remove unnecessary unicode prefixes
  - setup.cfg: Replace dashes by underscores
* Tue Jun  7 2022 cloud-devel@suse.de
- update to version 2.6.0
  - Update python testing classifier
  - Add Python3 yoga unit tests
  - Update master for stable/xena
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 2.5.0
  - Add Python3 xena unit tests
  - Use py3 as the default runtime for tox
  - Replace deprecated inspect.getargspec
  - Use TOX_CONSTRAINTS_FILE
  - Dropping lower constraints testing
  - Do not patch inspect.argspec directly
  - Changed minversion in tox to 3.18.0
  - Move flake8 as a pre-commit local target.
  - Dropping lower constraints references
  - Update master for stable/wallaby
* Sun May  2 2021 cloud-devel@suse.de
- update to version 2.4.0
  - Replace md5 with oslo version
  - Adding pre-commit
  - Add Python3 wallaby unit tests
  - Update master for stable/victoria
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.3.0
  - Update hacking for Python3
  - Remove translation sections from setup.cfg
  - Update master for stable/ussuri
  - Bump default tox env from py37 to py38
  - Switch to newer openstackdocstheme and reno versions
  - Cap jsonschema 3.2.0 as the minimal version
  - Stop to use the __future__ module.
  - zuul: port the legacy multinode grenade job
  - Add release notes links to doc index
  - trivial: Mock warnings
  - Imported Translations from Zanata
  - Bump bandit version
  - Align contributing doc with oslo's policy
  - [goal] Migrate testing to ubuntu focal
  - Add py38 package metadata
  - Add Python3 victoria unit tests
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.0.2
  - tox: Keeping going with docs
  - Drop use of six
  - Bump to hacking 2.x
  - Use unittest.mock instead of third party mock
  - remove outdated header
  - Import ABCs from collections.abc
  - [ussuri][goal] Drop python 2.7 support and testing
  - Migrate grenade jobs to py3
  - Provide stable getargspec() behavior for method fingerprinting
  - Update master for stable/train
  - Handle unregistered nested objects
  - gitignore: Ignore reno artefacts
* Fri Mar 13 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only build
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.36.1
  - Fix deprecation warnings
  - Cap Bandit below 1.6.0, update sphinx requirement, uncap jsonschema
  - OpenDev Migration Patch
  - Replace openstack.org git:// URLs with https://
  - Add Python 3 Train unit tests
  - Dropping the py35 testing
  - Resolve some issue with tox.ini, setup.cfg
  - Update master for stable/stein
  - Replace git.openstack.org URLs with opendev.org URLs
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.35.1
  - Update hacking version
  - Update mailinglist from dev to discuss
  - add python 3.7 unit test job
  - add lib-forward-testing-python3 test job
  - Lower ObjectVersionChecker logging to DEBUG level
  - Allow lists to be generated from any non-string iterable
  - import zuul job settings from project-config
  - Imported Translations from Zanata
  - Update reno for stable/rocky
  - Clean up .gitignore references to personal tools
  - Use template for lower-constraints
  - add python 3.6 unit test job
  - Add ListOfUUIDField
  - Switch to stestr
  - delete unused '='
* Sat Sep  1 2018 cloud-devel@suse.de
- update to version 1.33.3
  - Fixing UUID coerce function for unicode non uuid form
  - Remove stale pip-missing-reqs tox test
  - set default python to python3
  - fix tox python3 overrides
  - Add support version in exception output
  - Update reno for stable/queens
  - Zuul: Remove project name
  - pypy is not checked at gate
  - Add bindep.txt file to prevent fallback to generic list
  - Trivial: Update pypi url to new url
  - Update links in README
  - Allow escalation of UUID validation warning to error
  - Imported Translations from Zanata
  - Remove moxstubout usage
  - Add release notes link to README
  - Handle TZ change in iso8601 >=0.1.12
  - Don't force unicode strings for UUID coercion
  - Updated from global requirements
  - add lower-constraints job
  - Make the hash of a defaulted set field stable
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 1.31.2 (bsc#1078607)
  - Treat doc warnings as errors
  - Update .gitreview for stable/queens
  - Update UPPER_CONSTRAINTS_FILE for stable/queens
  - Remove log translations
  - Handle TZ change in iso8601 >=0.1.12
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 1.31.0 (bsc#1078607)
  - iso8601.is8601.Utc No Longer Exists
  - Fix wrong indent of releasenotes
  - Follow the new PTI for document build
  - Update reno for stable/pike
  - Updated from global requirements
  - Remove setting of version/release from releasenotes
  - Imported Translations from Zanata
  - Migrate to zuulv3 - move legacy jobs to project
  - Avoid tox_install.sh for constraints support
  - Use newer location for iso8601 UTC
  - Zuul: add file extension to playbook path
  - Add a TimestampedObject mixin
  - Add bandit to pep8 job
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.26.0
  - rearrange existing documentation to fit the new standard layout
  - Fix the object is unhashable when inheriting the class
  - Add unit test for unicode in object __repr__
  - Update URLs in documents according to document migration
  - Fix string interpolation in ValueError
  - Start adding some basic ovo examples (with an initial basic one)
  - Change Object schema type to be array instead of string.
  - [Fix gate]Update test requirement
  - fields: fix stringifying of objects when subclasses=True
  - Remove support for py34
  - Update reno for stable/ocata
  - Remove pbr warnerrors in favor of sphinx check
  - Updated from global requirements
  - Enable warning-is-error in doc build
  - switch from oslosphinx to openstackdocstheme
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.21.0:
  - Fix documentation typo
  - Fix a typo
  - Add Constraints support
  - Fix incorrect timestamp comment
  - Add reno for release notes management
  - Show team and repo badges on README
  - Changed the home-page link
  - Fix recursive deepcopy
  - Replace six.iteritems() with .items()
  - Add ObjectListBase concat methods
  - Fix get_schema() for Enum
  - JSON Schema get_schema implementation for last few fields
  - Refactor get_schema for patterned FieldTypes
  - Updated from global requirements
* Fri Oct 14 2016 tbechtold@suse.com
- Fix Url
* Tue Oct  4 2016 dmueller@suse.com
- * global-requirements.txt sync
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 1.17.0
  * Add get_schema for IPV6Address FieldType class
  * JSON schema get_schema implementation for more complex fields
  * Adds new fields and field types
  * Fix to_json_schema() call
  * Fix remotable object change tracking
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to 1.14.0:
  * Updated from global requirements
  * Add Python 3.5 classifier and venv
* Mon Aug  1 2016 tbechtold@suse.com
- update to 1.13.0:
  * Updated from global requirements
  * Imported Translations from Zanata
  * JSON schema get_schema implementation for common fields
  * JSON schema generation for versioned objects
  * Extend test_hashes to allow extra info gathering
  * Improved error message for Object.coerce
  * Fix ComparableVersionedObject in python 3.4
  * Add objectify decorator for readability
  * Fix a typo in Enum error path
  * Fix issue with coercing valid_values to a tuple
  * Replace safe_utils.getcallargs with inspect.getcallargs
  * Remove direct dependency on babel
  * Introduce fixture to enforce sorted order for object changes
  * Expose object context thru a public property
  * Fix compare_obj() to obey missing/unset fields
  * Add BaseEnumField valid_values introspection
  * Use primitive type name in ValueError for Object field coerce failure
  * Update formatting for example statemachine field
  * Add a pci address  field
  * Remove the executable bit from files
- update _service and switch to upstream spec file
* Mon Apr  4 2016 tbechtold@suse.com
- update to 1.8.0:
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
  [#] Adjust Requires
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.7.0:
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Deprecate current UUIDField behaviour
  * Make sure functions in child object registries work
  * Fix messages in exceptions raised due to invalid state transitions
  * Update translation setup
  * Updated from global requirements
  * Add ability to pass args/kwargs to obj_class init
  * Updated from global requirements
  * Added a state machine field
  * Use oslo_utils for tupleizing versions
  * Add temporary registry pattern to VersionedObjectRegistry
  * Updated from global requirements
  * Imported Translations from Zanata
  * Updated from global requirements
  * Move compare_obj to the fixture module for external consumption
  * Updated from global requirements
  * Fix MACAddress coerce method to validate string first
  * Updated from global requirements
  * Remove meaningless default value in __get__()
  * Added checking compat using manifest backports
  * Fixed nondeterministicness of extra_data test
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Clean up directory openstack/common
  * Use method is_compatible from olso_utils.versionutils
  * Trival: Remove 'MANIFEST.in'
  * Add a callable to gather extra data for fps
  * Add testing for ObjectVersionChecker fixture
  * Leverage dict comprehension in PEP-0274
  * Use version convert methods from oslo_utils.versionutils
  * Add netaddr-related field types
  * Updated from global requirements
  * Adds new MACAddressField
  * Fix the wrong reference for DeprecationWarning
  * cleanup tox.ini
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Fri Nov 20 2015 bwiedemann@suse.com
- update to 0.13.0:
  * Ensure__repr__ return value is encoded
  * Cleanup docstring for obj_tree_get_versions
  * Add warnings for deprecated IndirectionAPI methods
  * Make tests properly use object_class_action_versions()
  * Make class action calls use version manifest
  * Add SensitiveString field type
  * Fix obj_to_primitive() when used with a manifest
  * Move __contains__ from VersionedObjectDictCompat to VersionedObject
  * Add shields.io version/downloads links/badges into README.rst
  * Change ignore-errors to ignore_errors
  * Added test for DateTimeField in obj_get_change
  * Fix missing value types for log message
* Sat Sep 19 2015 tbechtold@suse.com
- update to 0.10.0:
  * Imported Translations from Zanata
* Tue Sep  1 2015 tbechtold@suse.com
- update to 0.9.0:
  * Updated from global requirements
  * Allow calling obj_to_primitive() with version_manifest
  * Switch back to iso format on the wire
  * Save and re-raise exception
  * Check for obj_relationships in List objects
  * Updated from global requirements
  * Make compat of object lists use manifest function
  * Add tests for subobject backporting by manifest
  * Make ObjectListBase a collections.Sequence
  * Switch from deprecated timeutils.isotime
  * Make direct call to object's obj_from_primitive
  * Add usage information
  * Imported Translations from Transifex
  * Updated from global requirements
  * Add validation on target_version arg when calling obj_to_primitive
* Tue Aug 11 2015 seife+obs@b1-systems.com
- update to 0.7.0:
  0.7.0
  * Fix error handling in the exception module on py3
  * Imported Translations from Transifex
  * Updated from global requirements
  * Add a new DictOfListOfStrings type of field
  0.6.0
  * Fix serializer supported version reporting in object_backport
  * Remove dict assumption from remotable decorator
  * Remove ununsed class in test.py
  * Replace 'hypervisor' with 'provided' version
  * Compound fields now coerce their elements' values
  * Move fixture dependencies to extras
  0.5.2
  * Sort child versions before generating fingerprint
  * Manual update the requirements
  * Remove classifiers not supported
  0.5.0
  * Add oslo.config to requirements
  * Add tox target to find missing requirements
  * fields: allow subclasses in ObjectField/ListOfObjectsField
  * Fix "comparason" typo in doc for ComparableVersionedObject
  * fields: report what the wrong type was when coerce fails
  * Decouple ObjectVersionChecker and VersionedObjectRegistry
  * Updated from global requirements
- update spec file requires from requires.txt
* Fri Jun 12 2015 tbechtold@suse.com
- update to 0.4.0:
  * Remove unnecessary openstack-common.conf
  * Updated from global requirements
- Adjust Requires according to requirements.txt
* Mon Jun  8 2015 tbechtold@suse.com
- update to 0.3.0:
  * Imported Translations from Transifex
  * Imported Translations from Transifex
  * Enhance documentation
  * Add delattr support
  * Imported Translations from Transifex
  * Enhance dict compat of VersionedObjectDictCompat
  * Drop outdated notes and docstrings
  * Add field name to error messages in object type checking
  * Adds missing WebOb in requirements.txt
  * Add enum fieldtype field
  * Get the indirection_api from the current VersionedObject class
  * Updated from global requirements
  * Imported Translations from Transifex
- Adjust Requires according to requirements.txt
* Sat May 16 2015 dmueller@suse.com
- update to 0.2.0:
  * Standardize setup.cfg summary for oslo libs
  * Update to the latest version of hacking
  * Copy the default value for field
  * Updated from global requirements
  * New config group for oslo_versionedobjects
* Wed Apr  8 2015 tbechtold@suse.com
- Initial packaging
